==> delegatecash-0.1.0.tgz: package/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { ethers } from 'ethers';
import { ADDRESS, ABI } from './constants';
import { getProvider, getDelegationType } from './utils';
var provider = getProvider();
var signer = provider.getSigner();
var delegationInterface = new ethers.utils.Interface(ABI);
var delegationContract = new ethers.Contract(ADDRESS, ABI, provider);
// READS
export var checkDelegateForAll = function (delegate, vault) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForAll(delegate, vault)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var checkDelegateForContract = function (delegate, vault, contract) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForContract(delegate, vault, contract)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var checkDelegateForToken = function (delegate, vault, contract, tokenId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForToken(delegate, vault, contract, tokenId)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getContractLevelDelegations = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getContractLevelDelegations(vault)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            contract: d[0],
                            delegate: d[1],
                        };
                    })];
        }
    });
}); };
export var getDelegatesForAll = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForAll(vault)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegatesForContract = function (vault, contract) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForContract(vault, contract)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegatesForToken = function (vault, contract, tokenId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForToken(vault, contract, tokenId)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegationsByDelegate = function (delegate) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegationsByDelegate(delegate)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            type: getDelegationType(d[0]),
                            vault: d[1],
                            delegate: d[2],
                            contract: d[3],
                            tokenId: Number(d[4]),
                        };
                    })];
        }
    });
}); };
export var getTokenLevelDelegations = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getTokenLevelDelegations(vault)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            contract: d[0],
                            tokenId: Number(d[1]),
                            delegate: d[2],
                        };
                    })];
        }
    });
}); };
//////
// WRITES
export var delegateForAll = function (delegate, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForAll(delegate, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var delegateForContract = function (delegate, contract, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForContract(delegate, contract, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var delegateForToken = function (delegate, contract, tokenId, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForToken(delegate, contract, tokenId, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeAllDelegates = function () { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).revokeAllDelegates()];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeDelegate = function (delegate) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).revokeDelegate(delegate)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeSelf = function () { return __awaiter(void 0, void 0, void 0, function () {
    var self;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, signer.getAddress()];
            case 1:
                self = _a.sent();
                return [4 /*yield*/, delegationContract.connect(signer).revokeSelf(self)];
            case 2: return [2 /*return*/, _a.sent()];
        }
    });
}); };
// RAW
export var rawDelegateForAll = function (delegate, value) {
    return delegationInterface.encodeFunctionData('delegateForAll', [delegate, value]);
};
export var rawDelegateForContract = function (delegate, contract, value) {
    return delegationInterface.encodeFunctionData('delegateForContract', [delegate, contract, value]);
};
export var rawDelegateForToken = function (delegate, contract, tokenId, value) {
    return delegationInterface.encodeFunctionData('delegateForToken', [delegate, contract, tokenId, value]);
};
export var rawRevokeAllDelegates = function () {
    return delegationInterface.encodeFunctionData('revokeAllDelegates');
};
export var rawRevokeDelegate = function (delegate) {
    return delegationInterface.encodeFunctionData('revokeDelegate', [delegate]);
};

==> delegatecash-0.2.0.tgz: package/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { ethers } from 'ethers';
import { ADDRESS, ABI } from './constants';
import { getProvider, getDelegationType } from './utils';
var provider = getProvider();
var signer = provider.getSigner();
var delegationInterface = new ethers.utils.Interface(ABI);
var delegationContract = new ethers.Contract(ADDRESS, ABI, provider);
// READS
export var checkDelegateForAll = function (delegate, vault) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForAll(delegate, vault)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var checkDelegateForContract = function (delegate, vault, contract) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForContract(delegate, vault, contract)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var checkDelegateForToken = function (delegate, vault, contract, tokenId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.checkDelegateForToken(delegate, vault, contract, tokenId)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getContractLevelDelegations = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getContractLevelDelegations(vault)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            contract: d[0],
                            delegate: d[1],
                        };
                    })];
        }
    });
}); };
export var getDelegatesForAll = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForAll(vault)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegatesForContract = function (vault, contract) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForContract(vault, contract)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegatesForToken = function (vault, contract, tokenId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegatesForToken(vault, contract, tokenId)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var getDelegationsByDelegate = function (delegate) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getDelegationsByDelegate(delegate)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            type: getDelegationType(d[0]),
                            vault: d[1],
                            delegate: d[2],
                            contract: d[3],
                            tokenId: Number(d[4]),
                        };
                    })];
        }
    });
}); };
export var getTokenLevelDelegations = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    var delegations;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.callStatic.getTokenLevelDelegations(vault)];
            case 1:
                delegations = _a.sent();
                return [2 /*return*/, delegations.map(function (d) {
                        return {
                            contract: d[0],
                            tokenId: Number(d[1]),
                            delegate: d[2],
                        };
                    })];
        }
    });
}); };
//////
// WRITES
export var delegateForAll = function (delegate, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForAll(delegate, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var delegateForContract = function (delegate, contract, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForContract(delegate, contract, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var delegateForToken = function (delegate, contract, tokenId, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).delegateForToken(delegate, contract, tokenId, value)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeAllDelegates = function () { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).revokeAllDelegates()];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeDelegate = function (delegate) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).revokeDelegate(delegate)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
export var revokeSelf = function (vault) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, delegationContract.connect(signer).revokeSelf(vault)];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };
// RAW
export var rawDelegateForAll = function (delegate, value) {
    return delegationInterface.encodeFunctionData('delegateForAll', [delegate, value]);
};
export var rawDelegateForContract = function (delegate, contract, value) {
    return delegationInterface.encodeFunctionData('delegateForContract', [delegate, contract, value]);
};
export var rawDelegateForToken = function (delegate, contract, tokenId, value) {
    return delegationInterface.encodeFunctionData('delegateForToken', [delegate, contract, tokenId, value]);
};
export var rawRevokeAllDelegates = function () {
    return delegationInterface.encodeFunctionData('revokeAllDelegates');
};
export var rawRevokeDelegate = function (delegate) {
    return delegationInterface.encodeFunctionData('revokeDelegate', [delegate]);
};
